# Installation:
```
pip install PyTerms
```

# Usage Example:
```py
from PyTerms import PyTerm

PyTerm.clear()
PyTerm.set_title("Whow ! Work on Linux and Windows, also support | :o")
PyTerm.prints("WoW i can make lot of thread to write this line and they never make shit on my terminal :o")
```
